These methods take mixed-effects models fitted with the nlme package and create formatted character strings report the results in accordance with APA manuscript guidelines.
# S3 method for lme
apa_print(x, conf.int = 0.95, in_paren = FALSE, est_name = NULL, ...)# S3 method for anova.lme
apa_print(x, in_paren = FALSE, ...)
apa_print()-methods return a named list of class apa_results containing the following elements:
One or more character strings giving point estimates, confidence intervals, and confidence level. A single string is returned in a vector; multiple strings are returned as a named list. If no estimate is available the element is NULL.
One or more character strings giving the test statistic, parameters (e.g., degrees of freedom), and p-value. A single string is returned in a vector; multiple strings are returned as a named list. If no estimate is available the element is NULL.
One or more character strings comprised `estimate` and `statistic`. A single string is returned in a vector; multiple strings are returned as a named list.
A data.frame of class apa_results_table that contains all elements of estimate and statistics. This table can be passed to apa_table() for reporting.
Column names in apa_results_table are standardized following the broom glossary (e.g., term, estimate
conf.int, statistic, df, df.residual, p.value). Additionally, each column is labelled (e.g., $\hat{\eta}^2_G$ or $t$) using the tinylabels package and these labels are used as column names when an apa_results_table is passed to apa_table().
A (non-)linear mixed-effects model fitted with nlme::lme() or
nlme::nlme()
Numeric specifying the required confidence level or a named list
of additional arguments that are passed to nlme::intervals.lme().
Logical. Whether the formatted string is to be reported in
parentheses. If TRUE, parentheses in the formatted string (e.g., those
enclosing degrees of freedom) are replaced with brackets.
An optional character. The label to be used for fixed-effects coefficients.
Further arguments that may be passed to apa_num to format estimates (i.e., columns estimate and conf.int).
Other apa_print:
apa_print.BFBayesFactor(),
apa_print.aov(),
apa_print.emmGrid(),
apa_print.glht(),
apa_print.htest(),
apa_print.list(),
apa_print.lm(),
apa_print.merMod(),
apa_print()
library(nlme)
fm1 <- lme(distance ~ age, data = Orthodont, method = "ML") # random is ~ age
apa_print(fm1, conf.int = .9)
# ANOVA-like tables
single_anova <- anova(fm1)
apa_print(single_anova)
Run the code above in your browser using DataLab