These methods take objects from various R functions that calculate ANOVA to create formatted character
strings to report the results in accordance with APA manuscript guidelines. For anova-objects from model comparisons see apa_print.list.
apa_print.aov(x, ...)apa_print.summary.aov(x, ...)
apa_print.aovlist(x, ...)
apa_print.summary.aovlist(x, ...)
apa_print.Anova.mlm(x,
correction = getOption("papaja.sphericity_correction"),
intercept = FALSE, ...)
apa_print.summary.Anova.mlm(x,
correction = getOption("papaja.sphericity_correction"),
intercept = FALSE, ...)
apa_print.afex_aov(x,
correction = getOption("papaja.sphericity_correction"),
intercept = FALSE, ...)
apa_print.anova(x, ...)
apa_print.manova(x, test = "Pillai", ...)
apa_print.summary.manova(x, ...)
Output object. See details.
Arguments passed on to print_anova
Data.frame. A data.frame of class apa_variance_table as returned by arrange_anova.
Logical. Indicates if intercept test should be included in output.
Character. The effect-size measure to be calculated; can be either ges for generalized eta-squared, pes for partial eta-squared or es for eta-squared.
Note that eta-squared is calculated correctly if and only if the design is balanced.
Logical. Indicates if mean squared errors should be included in output. Default is TRUE.
Character. The names of the factors that are observed, (i.e., not manipulated). Necessary for calculation of generalized eta-squared; otherwise ignored.
Logical. Indicates if the formated string will be reported inside parentheses. See details.
Character. In the case of repeated-measures ANOVA, the type of sphericity correction to be used (GG for Greenhouse-Geisser or HF for Huyn-Feldt methods or none). Default is GG.
Logical. Indicates if intercept test should be included in output.
For MANOVA, the multivariate test statistic to be reported, see summary.manova.
apa_print.aov and related functions return a named list containing the following components according to the input:
statisticA named list of character strings giving the test statistic, parameters, and p value for each factor.
estimateA named list of character strings giving the effect size estimates for each factor.
full_resultA named list of character strings comprised of estimate and statistic for each factor.
tableA data.frame containing the complete ANOVA table, which can be passed to apa_table.
The factor names are sanitized to facilitate their use as list names (see Value section). Parentheses
are omitted and other non-word characters are replaced by _.
If in_paren is TRUE parentheses in the formatted string, such as those surrounding degrees
of freedom, are replaced with brackets.
Bakeman, R. (2005). Recommended effect size statistics for repeated measures designs. Behavior Research Methods , 37 (3), 379--384. doi:10.3758/BF03192707
Other apa_print: apa_print.BFBayesFactor,
apa_print.emmGrid,
apa_print.glht,
apa_print.glm,
apa_print.htest,
apa_print.list, apa_print
# NOT RUN {
## From Venables and Ripley (2002) p. 165.
npk_aov <- aov(yield ~ block + N * P * K, npk)
apa_print(npk_aov)
# }
Run the code above in your browser using DataLab