Takes glht objects to create formatted character strings to report the results in
accordance with APA manuscript guidelines. These methods are not properly tested and should be
considered experimental.
apa_print.glht(x, test = multcomp::adjusted(), ...)apa_print.summary.glht(x, ci = 0.95, in_paren = FALSE, ...)
Object
Function. Computes p-values (adjusted for multiple comparisons).
Arguments passed on to printnum
Numeric. Can be either a single value, vector, or matrix.
Numeric. If NULL (default) the function tries to obtain confidence intervals from x.
Other confidence intervals can be supplied as a vector of length 2 (lower and upper boundary, respectively)
with attribute conf.level, e.g., when calculating bootstrapped confidence intervals.
Logical. Indicates if the formated string will be reported inside parentheses.
apa_print() returns a list containing the following components according to the input:
statisticA character string giving the test statistic, parameters (e.g., degrees of freedom), and p value.
estimateA character string giving the descriptive estimates and confidence intervals if possible
full_resultA joint character string comprised of est and stat.
tableA data.frame containing the complete contrast table, which can be passed to apa_table.
If in_paren is TRUE parentheses in the formated string, such as those surrounding degrees
of freedom, are replaced with brackets.
Other apa_print: apa_print.BFBayesFactor,
apa_print.aov,
apa_print.emmGrid,
apa_print.glm,
apa_print.htest,
apa_print.list, apa_print