lsmeans objects methods to create formatted chraracter strings to report the results in
accordance with APA manuscript guidelines. Not yet ready for use.
"apa_print"(x, test = multcomp::adjusted(), ...)
"apa_print"(x, ci = 0.95, in_paren = FALSE, ...)
"apa_print"(x, ...)
"apa_print"(x, ci = 0.95, contrast_names = NULL, in_paren = FALSE, ...)printnum to format the estimate.NULL (default) the function tries to obtain confidence intervals from x.
Other confidence intervals can be supplied as a vector of length 2 (lower and upper boundary, respectively)
with attribute conf.level, e.g., when calculating bootstrapped confidence intervals.apa_print() returns a list containing the following components according to the input:htest objects. Due to the large number of functions
that produce these objects and their idiosyncracies, the produced strings may sometimes be inaccurate. If you
experience inaccuracies you may report these here (please include
a reproducible example in your report!).ADJUSTED CONFIDENCE INTERVALS
stat_name and est_name are placed in the output string and are thus passed to pandoc or LaTeX through
kntir. Thus, to the extent it is supported by the final document type, you can pass LaTeX-markup to format the
final text (e.g., \\tau yields $\tau$).
If in_paren is TRUE parentheses in the formated string, such as those surrounding degrees
of freedom, are replaced with brackets.
apa_print.aov,
apa_print.htest,
apa_print.list, apa_print.lm,
apa_print