cite_r(file = NULL, prefix = "R-", footnote = FALSE, pkgs = "all").bib-file holding the references.pkgs = "all" (default) all packages in file
are cited.footnote = FALSE a character string is returned, otherwise a named list with the elements r
and pkgs.
footnote = FALSE a character string citing R and R-packages including version
numbers is returned. Otherwise a named list with the elements r and pkgs is returned. The
former element holds a character string citing R and a reference to a footnote; the latter element contains
a character string for the footnote citing R-packages. For correct rendering, the footnote string needs
to be a separate paragraph in the Markdown document.
r_refs, write_bib